/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.farm.model;

import java.io.IOException;
import nl.cloudfarming.client.model.EntityManager;
import org.openide.filesystems.FileObject;

/**
 *
 *  Interface for managing persistence of crop fields
 * 
 * @author Timon Veenstra <monezz@gmail.com>
 */
public interface CropFieldManager extends EntityManager {
    /**
     * loads a CropField from a fileobject
     *
     * @param fileObject
     * @return
     * @throws DataStorageException crop field could not be loaded
     */
    CropField loadCropField(FileObject cropFieldObject) throws IOException;

    /**
     * save a new crop field
     * 
     * @param cropField
     * @param targetFolder
     * @throws DataStorageException crop field could not be saved
     */
    void saveToFolder(CropField cropField, FileObject targetFolder) throws IOException; 

    /**
     * save an existing crop field
     * 
     * @param cropField
     * @param fileObject
     * @throws DataStorageException crop field could not be saved
     */
    void saveToFile(CropField cropField, FileObject fileObject) throws IOException;    
}
