/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.farm.model;

import javax.swing.JTextField;
import nl.cloudfarming.client.model.IssuingAgency;
import nl.cloudfarming.client.util.swing.MessagePanel;
import nl.cloudfarming.client.util.swing.beanbinding.NonEmptyStringValidator;
import org.jdesktop.beansbinding.*;

/**
 * farm details panel bound to an existing {@link Farm}.
 *
 * @author johan & Merijn Zengers
 */
public class FarmDetailsEditPanel extends FarmDetailsPanel {

    protected JTextField farmIssuingAgencyTextField;
    private Farm farm;
    private ELProperty farmNameProperty = ELProperty.create("${text_ON_ACTION_OR_FOCUS_LOST}");
    private BeanProperty farmPropName = BeanProperty.create(Farm.PROP_NAME);
    private Binding farmNameBinding;
    private BindingGroup farmBindingGroup = new BindingGroup();
    private MessagePanel messagePanel;

    public FarmDetailsEditPanel(Farm farm) {
        super(new JTextField(), farm.getAddress());
        farmIssuingAgencyTextField = (JTextField) farmIssuingAgencyComponent;
        this.farm = farm;

        initComponents();
        bind();
        initValues();
    }

    private void initComponents() {
        // properties that affect the URIs of other entities in the project are immutable for now:
        farmIssuingAgencyTextField.setEditable(false);
        farmRegistrationNumberTextField.setEditable(false);

        messagePanel = new MessagePanel(MessagePanel.LARGE_ICON);
        this.add(messagePanel, "span");

    }

    /**
     * Bind the {@link FarmDetailsEditPanel#farmNameTextField} to {@link Farm#name}
     */
    private void bind() {
        farmNameBinding = Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ_WRITE,
                farm, farmPropName, farmNameTextField, farmNameProperty);
        farmNameBinding.setValidator(new NonEmptyStringValidator());
        farmBindingGroup.addBinding(farmNameBinding);
        farmBindingGroup.bind();
    }

    /**
     * Init the values of the fields
     */
    private void initValues() {
        setFarmName(farm.getName());
        setFarmIssuingAgency(farm.getIssuingAgency());
        setFarmRegistrationNumber(farm.getRegistrationNumber());
    }

    /**
     * Get the {@link Farm} who's properties are displayed on the panel
     * @return 
     */
    public Farm getFarm() {
        return farm;
    }

    /**
     * Get the {@link FarmDetailsEditPanel#messagePanel} which can display errors
     *
     * @return
     */
    public MessagePanel getErrorPanel() {
        return messagePanel;
    }

    /**
     * Get the {@link IssuingAgency} from this panel
     * @return 
     */
    @Override
    public IssuingAgency getFarmIssuingAgency() {
        return IssuingAgency.valueOf(farmIssuingAgencyTextField.getText().trim());
    }

    /**
     * Set the {@link IssuingAgency} for this panel
     * @param issuingAgency 
     */
    @Override
    public void setFarmIssuingAgency(IssuingAgency issuingAgency) {
        farmIssuingAgencyTextField.setText(issuingAgency.name());
    }
    
    
}
